@@ -9,8 +9,8 @@ from method.resources.Report import ReportResource
 from method.resources.RoutingNumber import RoutingNumberResource
 from method.resources.Webhook import WebhookResource
 from method.resources.HealthCheck import PingResponse, HealthCheckResource
-from method.resources.Connection import ConnectionResource
 from method.resources.Simulate import SimulateResource
+from method.resources.Transaction import TransactionResource
 
 
 class Method:
@@ -24,8 +24,8 @@ class Method:
     routing_numbers: RoutingNumberResource
     webhooks: WebhookResource
     healthcheck: HealthCheckResource
-    connections: ConnectionResource
     simulate: SimulateResource
+    transaction: TransactionResource
 
     def __init__(self, opts: ConfigurationOpts = None, **kwargs: ConfigurationOpts):
         _opts: ConfigurationOpts = {**(opts or {}), **kwargs}  # type: ignore
@@ -41,8 +41,8 @@ class Method:
         self.routing_numbers = RoutingNumberResource(config)
         self.webhooks = WebhookResource(config)
         self.healthcheck = HealthCheckResource(config)
-        self.connections = ConnectionResource(config)
         self.simulate = SimulateResource(config)
+        self.transaction = TransactionResource(config)
 
     def ping(self) -> PingResponse:
         return self.healthcheck.get()
