@@ -42,6 +42,10 @@ class Resource:
     def _get_with_sub_path(self, path: str) -> Any:
         return self.client(path).GET().json().get('data')
 
+    @MethodError.catch
+    def _get_with_sub_path_and_params(self, path: str, params: Dict) -> Any:
+        return self.client(path).GET(params=params).json().get('data')
+
     @MethodError.catch
     def _list(self, params: Optional[Dict] = None) -> List[Any]:
         return self.client.GET(params=params).json().get('data')
@@ -84,4 +88,4 @@ class Resource:
 
     @MethodError.catch
     def _post_with_id(self, _id: str, data: Dict) -> Any:
-        return self.client(_id).POST(data=json.dumps(data)).json().get('data')
\ No newline at end of file
+        return self.client(_id).POST(data=json.dumps(data)).json().get('data')
